/**
	$Id: AgentSignalReceiver.java 4512 2008-09-11 20:05:50Z jari $

	Copyright (C) Authors contributing to this file.

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.clients.jobagent;

import net.sf.basedb.clients.jobagent.handlers.SignalRequestHandler;
import net.sf.basedb.core.signal.SocketSignalReceiver;
import net.sf.basedb.util.jobagent.JobAgentServerConnection;

/**
	Signal receiver implementation for job agents that is compatible with
	the {@link SocketSignalReceiver}. This implementation will however not
	open a port of it's own, but uses the regular job agent control port.
	Incoming signals will first be handled by a {@link SignalRequestHandler}
	which forwards signals to this class by calling {@link #processSignalMessage(String)}.
	
	@author nicklas
	@version 2.6
	@base.modified $Date: 2008-09-11 22:05:50 +0200 (Thu, 11 Sep 2008) $
*/
public class AgentSignalReceiver
	extends SocketSignalReceiver
{

	private final Agent agent;
	
	public AgentSignalReceiver(Agent agent)
	{
		this.agent = agent;
	}
	
	/*
		From the SignalReceiver interface
		-------------------------------------------
	*/
	/**
		Initialise the receiver. No parameters are needed.
		Port number will be taken from job agent configuration.
	*/
	@Override
	public void init(String params)
	{
		super.init("port=" + agent.getPort() + "&forward=1");
	}
	// -------------------------------------------

	/**
		Do not open any socket. Signals will be sent to a {@link 
		JobAgentServerConnection} and routed to this class via a {@link 
		SignalRequestHandler}.
	*/
	@Override
	protected void listenOnSocket()
	{}

	/**
		Make this method public so {@link SignalRequestHandler}
		can call it.
	*/
	@Override
	public void processSignalMessage(String message)
	{
		super.processSignalMessage(message);
	}

	
}
