/*
	$Id: ItemResultIterator.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2005 Samuel Andersson, Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

import net.sf.basedb.core.query.ResultIterator;
import net.sf.basedb.core.data.BasicData;

/**
	Return the results of an {@link ItemQuery} as an iterator. 
	
	@author Samuel, Nicklas
	@version 2.0
	@see ItemQuery#iterate(DbControl)
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (Mon, 06 Apr 2009) $
*/
public class ItemResultIterator<I extends BasicItem>
	implements ResultIterator<I>
{
	/**
		The internal iterator of BasicData objects.
	*/
	private final ScrollIterator<? extends BasicData> data;

	/**
		The DbControl tthat was used in the query.
	*/
	private final DbControl dc;

	/**
		The class of the items returned by the query (and this object). 
	*/
	private final Class<I> itemClass;
	
	/**
		The total number of items.
	*/
	private final long totalCount;
	
	/**
		The type of items returned by the query.
	*/
	private final Item itemType;

	ItemResultIterator(ScrollIterator<? extends BasicData> data, DbControl dc, Class<I> itemClass, long totalCount)
	{
		assert data != null : "data == null";
		assert dc != null : "dc == null";
		assert itemClass != null : "itemClass == null";
		this.data = data;
		this.dc = dc;
		this.itemClass = itemClass;
		this.itemType = Item.fromItemClass(itemClass);
		this.totalCount = totalCount;
	}

	/**
		From the QueryResult interface
		---------------------------------
	*/
	public long getTotalCount()
	{
		return totalCount;
	}
	// ---------------------------------
	/**
		From the ResultIterator interface
		---------------------------------
	*/
	public void close()
	{
		data.close();
	}
	public boolean isClosed()
	{
		return data.isClosed();
	}
	// ---------------------------------

	/*
		From the Iterator interface
		--------------------------------
	*/
	public boolean hasNext()
	{
		return data.hasNext();
	}
	public I next()
	{
		BasicData dataObject = data.next();
		I itemObject = null;
		if (dataObject != null)
		{
			itemObject = dc.getItem(itemClass, dataObject);
		}
		return itemObject;
	}
	/**
		Not supported.
		@throws UnsupportedOperationException Always
	*/
	public void remove()
	{
		throw new UnsupportedOperationException();
	}
	// ---------------------------------
	
	/**
		Get the type of items contained in this list.
		@return An {@link Item} object or null if not known
	*/
	public Item getItemType()
	{
		return itemType;
	}

}
