/*
	$Id: ExperimentData.java 5818 2011-10-21 11:15:41Z nicklas $
	
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Johan Enell, Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg
	
	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/
	
	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.
	
	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

import java.util.Set;
import java.util.HashSet;
import java.util.Date;

/**
	Holds information about an experiment.
	
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.Experiment
	@see <a href="../../../../../../html/developer/api/data_api.experiments.html">Developer documentation: Experiments and analysis</a>
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (Fri, 21 Oct 2011) $
	@hibernate.class table="`Experiments`" lazy="true"
*/
public class ExperimentData
	extends CommonData
	implements DiskConsumableData, RegisteredData, LoggableData
{

	public ExperimentData()
	{}

	/*
		From the DiskConsumableData interface
		-------------------------------------------
	*/
	private DiskUsageData diskUsage;
	public DiskUsageData getDiskUsage()
	{
		if(diskUsage == null) diskUsage = new DiskUsageData();
		return diskUsage;
	}
	void setDiskUsage(DiskUsageData diskUsage)
	{
		this.diskUsage = diskUsage;
	}
	// -------------------------------------------
	/*
		From the RegisteredData interface
		-------------------------------------------
	*/
	private Date entryDate;
	public Date getEntryDate()
	{
		return entryDate;
	}
	public void setEntryDate(Date entryDate)
	{
		this.entryDate = entryDate;
	}
	// -------------------------------------------

	private long bytes;
	/**
		The number of bytes the analysed data in this experiment occupies on disk. 
		Updates to this column are done through SQL statements and not
		through this object.
		@hibernate.property column="`bytes`" type="long" not-null="true" update="false"
	*/
	public long getBytes()
	{
		return bytes;
	}
	public void setBytes(long bytes)
	{
		this.bytes = bytes;
	}

	private String rawDataType;
	/**
		Get the name of the raw data type used in this experiment.
		@hibernate.property column="`rawdatatype`" type="string" length="255" not-null="true" update="false"
	*/
	public String getRawDataType()
	{
		return rawDataType;
	}
	public void setRawDataType(String rawDataType)
	{
		this.rawDataType = rawDataType;
	}
	
	private DirectoryData directory;
	/**
		Get the associated {@link DirectoryData} item directory where
		it is recommended for plugins to save files related to the experiment.
		@hibernate.many-to-one outer-join="false"
		@hibernate.column name="`directory_id`" not-null="false"
	*/
	public DirectoryData getDirectory()
	{
		return directory;
	}
	public void setDirectory(DirectoryData directory)
	{
		this.directory = directory;
	}
	
	public static final int MAX_AUTHORS_LENGTH = 65535;
	private String authors;
	/**
		Get the authors for this experiment.
		@hibernate.property column="`authors`" type="text" not-null="false"
	*/
	public String getAuthors()
	{
		return authors;
	}
	public void setAuthors(String authors)
	{
		this.authors = authors;
	}

	public static final int MAX_AFFILIATIONS_LENGTH = 65535;
	private String affiliations;
	
	/**
		Get the affiliations for this experiment.
		@hibernate.property column="`affiliations`" type="text" not-null="false"
	*/
	public String getAffiliations()
	{
		return affiliations;
	}
	public void setAffiliations(String affiliations)
	{
		this.affiliations = affiliations;
	}

	public static final int MAX_TITLE_LENGTH = 65535;
	private String title;
	/**
		Get the title for this experiment.
		@hibernate.property column="`title`" type="text" not-null="false"
	*/
	public String getTitle()
	{
		return title;
	}
	public void setTitle(String title)
	{
		this.title = title;
	}
	
	public static final int MAX_ABSTRACT_LENGTH = 65535;
	private String theAbstract;
	/**
		Get the abstract for this experiment.
		@hibernate.property column="`abstract`" type="text" not-null="false"
	*/
	public String getAbstract()
	{
		return theAbstract;
	}
	public void setAbstract(String theAbstract)
	{
		this.theAbstract = theAbstract;
	}

	public static final int MAX_EXPERIMENT_DESIGN_LENGTH = 65535;
	private String experimentDesign;
	/**
		Get the experimental design for this experiment.
		@hibernate.property column="`experiment_design`" type="text" not-null="false"
	*/
	public String getExperimentDesign()
	{
		return experimentDesign;
	}
	public void setExperimentDesign(String experimentDesign)
	{
		this.experimentDesign = experimentDesign;
	}
	
	public static final int MAX_EXPERIMENT_TYPE_LENGTH = 65535;
	private String experimentType;
	/**
		Get the experimental type for this experiment.
		@hibernate.property column="`experiment_type`" type="text" not-null="false"
	*/
	public String getExperimentType()
	{
		return experimentType;
	}
	public void setExperimentType(String experimentType)
	{
		this.experimentType = experimentType;
	}

	public static final int MAX_PUBLICATION_LENGTH = 65535;
	private String publication;
	/**
		Get the publication for this experiment.
		@hibernate.property column="`publication`" type="text" not-null="false"
	*/
	public String getPublication()
	{
		return publication;
	}
	public void setPublication(String publication)
	{
		this.publication = publication;
	}

	public static final int MAX_PUBMEDID_LENGTH = 255;
	private String pubMedId;
	/**
		Get the publication for this experiment.
		@hibernate.property column="`pubmed_id`" type="string" not-null="false" length="255"
	*/
	public String getPubMedId()
	{
		return pubMedId;
	}
	public void setPubMedId(String pubMedId)
	{
		this.pubMedId = pubMedId;
	}

	private Date publicationDate;
	/**
		Get the publication date for this experiment.
		@hibernate.property column="`publication_date`" type="date" not-null="false"
	*/
	public Date getPublicationDate()
	{
		return publicationDate;
	}
	public void setPublicationDate(Date publicationDate)
	{
		this.publicationDate = publicationDate;
	}

	private VirtualDbData virtualDb;
	/**
		Get the virtual database this experiment stores the analyzed data in.
		@hibernate.many-to-one column="`virtualdb_id`" not-null="true" unique="true" outer-join="false" 
			update="false" cascade="save-update"
	*/
	public VirtualDbData getVirtualDb()
	{
		if (virtualDb == null)
		{
			virtualDb = new VirtualDbData();
			virtualDb.setExperiment(this);
		}
		return virtualDb;
	}
	public void setVirtualDb(VirtualDbData virtualDb)
	{
		this.virtualDb = virtualDb;
	}

	private Set<RawBioAssayData> rawBioAssays;
	/**
		A set that manages which raw bioassays are available in the experiment.
		@hibernate.set table="`ExperimentRawBioAssays`" lazy="true"
		@hibernate.collection-key column="`experiment_id`"
		@hibernate.collection-many-to-many column="`rawbioassay_id`" class="net.sf.basedb.core.data.RawBioAssayData"
	*/
	public Set<RawBioAssayData> getRawBioAssays()
	{
		if (rawBioAssays == null) rawBioAssays = new HashSet<RawBioAssayData>();
		return rawBioAssays;
	}
	void setRawBioAssays(Set<RawBioAssayData> rawBioAssays)
	{
		this.rawBioAssays = rawBioAssays;
	}
	
	private Set<BioAssaySetData> bioAssaySets;
	/**
		This is the inverse end.
		@see BioAssaySetData#getExperiment()
		@hibernate.set lazy="true" inverse="true"
		@hibernate.collection-key column="`experiment_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.BioAssaySetData"
	*/
	Set<BioAssaySetData> getBioAssaySets()
	{
		return bioAssaySets;
	}
	void setBioAssaySets(Set<BioAssaySetData> bioAssaySets)
	{
		this.bioAssaySets = bioAssaySets;
	}

	private Set<TransformationData> transformations;
	/**
		This is the inverse end.
		@see TransformationData#getExperiment()
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`experiment_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.TransformationData"
	*/
	Set<TransformationData> getTransformations()
	{
		return transformations;
	}
	void setTransformations(Set<TransformationData> transformations)
	{
		this.transformations = transformations;
	}
	
	private Set<JobData> jobs;
	/**
		This is the inverse end.
		@see JobData#getExperiment()
		@since 2.4
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`experiment_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.JobData"
	*/
	Set<JobData> getJobs()
	{
		return jobs;
	}
	void setJobs(Set<JobData> jobs)
	{
		this.jobs = jobs;
	}

	private Set<AnnotationTypeData> experimentalFactors;
	/**
		The annotation types which describes the experimental factors for this experiment.
		@hibernate.set table="`ExperimentalFactors`" lazy="true"
		@hibernate.collection-key column="`experiment_id`"
		@hibernate.collection-many-to-many column="`annotationtype_id`" class="net.sf.basedb.core.data.AnnotationTypeData"
	*/
	public Set<AnnotationTypeData> getExperimentalFactors()
	{
		if (experimentalFactors == null)
		{
			experimentalFactors = new HashSet<AnnotationTypeData>();
		}
		return experimentalFactors;
	}
	void setExperimentalFactors(Set<AnnotationTypeData> experimentalFactors)
	{
		this.experimentalFactors = experimentalFactors;
	}

	private Set<ReporterListData> reporterLists;
	/**
		This is the inverse end.
		@see ReporterListData#getExperiment()
		@since 2.7
		@hibernate.set lazy="true" inverse="true" cascade="delete"
		@hibernate.collection-key column="`experiment_id`"
		@hibernate.collection-one-to-many class="net.sf.basedb.core.data.ReporterListData"
	*/
	Set<ReporterListData> getReporterLists()
	{
		return reporterLists;
	}
	void setReporterLists(Set<ReporterListData> reporterLists)
	{
		this.reporterLists = reporterLists;
	}

}
