/*
  $Id: ExtraValueData.java 5818 2011-10-21 11:15:41Z nicklas $

	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

  BASE is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 3
  of the License, or (at your option) any later version.

  BASE is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	This represents the use of extra values that have been calculated for a bioassayset.
	Each bioassay set may only have one extra value of each type.
	
	@author Nicklas
	@version 2.0
	@see net.sf.basedb.core.ExtraValue
	@see <a href="../../../../../../html/developer/api/data_api.experiments.html">Developer documentation: Experiments and analysis</a>
	@hibernate.class table="`ExtraValues`" lazy="false"
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (Fri, 21 Oct 2011) $
*/
public class ExtraValueData
	extends BasicData
	implements FileStoreEnabledData
{
	public ExtraValueData()
	{}
	
	/*
		From the FileStoreEnabledData interface
		-------------------------------------------
	*/
	private FileSetData fileSet;
	public FileSetData getFileSet()
	{
	   return fileSet;
	}
	public void setFileSet(FileSetData fileSet)
	{
	   this.fileSet = fileSet;
	}
	// -------------------------------------------
		
	private BioAssaySetData bioAssaySet;
	/**
		Get the bioassayset this extra value belongs to.
		@hibernate.many-to-one column="`bioassayset_id`" not-null="true" outer-join="false" 
			update="false" unique-key="uniqueextravalue"
	*/
	public BioAssaySetData getBioAssaySet()
	{
		return bioAssaySet;
	}
	public void setBioAssaySet(BioAssaySetData bioAssaySet)
	{
		this.bioAssaySet = bioAssaySet;
	}
	
	private ExtraValueTypeData extraValueType;
	/**
		Get the type of this extra value.
		@hibernate.many-to-one column="`extravaluetype_id`" not-null="true" outer-join="false" 
			update="false" unique-key="uniqueextravalue"
	*/
	public ExtraValueTypeData getExtraValueType()
	{
		return extraValueType;
	}
	public void setExtraValueType(ExtraValueTypeData extraValueType)
	{
		this.extraValueType = extraValueType;
	}

	private DataCubeExtraValueData dataCubeExtraValue;
	/**
		Get the data cube extra value where the extra values are stored.
		@hibernate.many-to-one column="`datacubeextravalue_id`" not-null="true" 
			outer-join="false" update="false" cascade="save-update"
	*/
	public DataCubeExtraValueData getDataCubeExtraValue()
	{
		return dataCubeExtraValue;
	}
	public void setDataCubeExtraValue(DataCubeExtraValueData dataCubeExtraValue)
	{
		this.dataCubeExtraValue = dataCubeExtraValue;
	}

	private int numValues;
	/**
		The number of extra values that have been inserted.
		@hibernate.property column="`values`" type="int" not-null="true" update="false"
	*/
	public int getNumValues()
	{
		return numValues;
	}
	public void setNumValues(int numValues)
	{
		this.numValues = numValues;
	}

	private int numFileValues;
	/**
		The number of extra values that are stored in files.
		@hibernate.property column="`file_values`" type="int" not-null="true"
	*/
	public int getNumFileValues()
	{
		return numFileValues;
	}
	public void setNumFileValues(int numFileValues)
	{
		this.numFileValues = numFileValues;
	}

	
	private JobData job;
	/**
		Get the job that was used to execute this calculate this extra value. Null is allowed.
		@hibernate.many-to-one column="`job_id`" not-null="false" outer-join="false" update="false"
	*/
	public JobData getJob()
	{
		return job;
	}
	public void setJob(JobData job)
	{
		this.job = job;
	}

}
