/**
	$Id: TypeWrapper.java 5475 2010-11-03 14:02:49Z nicklas $

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.hibernate;

import org.hibernate.type.BooleanType;
import org.hibernate.type.DateType;
import org.hibernate.type.DoubleType;
import org.hibernate.type.FloatType;
import org.hibernate.type.IntegerType;
import org.hibernate.type.LongType;
import org.hibernate.type.ShortType;
import org.hibernate.type.StringType;
import org.hibernate.type.TextType;
import org.hibernate.type.TimestampType;

/**
	Wrapper class for Hibernate types that will try to
	"hide" issues with the redesign of the type system in Hibernate
	that is going on in Hibernate 3.5.2 --> Hibernate 3.6.
	
	@author Nicklas
	@since 2.16
	@base.modified $Date: 2010-11-03 15:02:49 +0100 (Wed, 03 Nov 2010) $
*/
public class TypeWrapper<T extends org.hibernate.type.Type>
{
	
	public static final TypeWrapper<ShortType> SHORT = 
		new TypeWrapper<ShortType>(ShortType.INSTANCE);

	public static final TypeWrapper<IntegerType> INTEGER = 
		new TypeWrapper<IntegerType>(IntegerType.INSTANCE);

	public static final TypeWrapper<LongType> LONG = 
		new TypeWrapper<LongType>(LongType.INSTANCE);

	public static final TypeWrapper<FloatType> FLOAT = 
		new TypeWrapper<FloatType>(FloatType.INSTANCE);

	public static final TypeWrapper<DoubleType> DOUBLE = 
		new TypeWrapper<DoubleType>(DoubleType.INSTANCE);

	public static final TypeWrapper<StringType> STRING = 
		new TypeWrapper<StringType>(StringType.INSTANCE);

	public static final TypeWrapper<TextType> TEXT = 
		new TypeWrapper<TextType>(TextType.INSTANCE);

	public static final TypeWrapper<BooleanType> BOOLEAN = 
		new TypeWrapper<BooleanType>(BooleanType.INSTANCE);
	
	public static final TypeWrapper<DateType> DATE = 
		new TypeWrapper<DateType>(DateType.INSTANCE);

	public static final TypeWrapper<TimestampType> TIMESTAMP = 
		new TypeWrapper<TimestampType>(TimestampType.INSTANCE);


	private final T hibernateType;
	private final int sqlType;
	
	protected TypeWrapper(T hibernateType)
	{
		this.hibernateType = hibernateType;
		this.sqlType = hibernateType instanceof org.hibernate.type.SingleColumnType ?
			((org.hibernate.type.SingleColumnType)hibernateType).sqlType() : 0;
	}
	
	/**
		Get the underlying Hibernate type.
	*/
	public T getHibernateType()
	{
		return hibernateType;
	}
	
	/**
		Get the SQL code for database columns that can store this type.
		@return A code, or 0 if not applicable to the given type
		@see java.sql.Types
	*/
	public int getSQLType()
	{
		return sqlType;
	}
	

}
