/**
	$Id: AssayField.java 5373 2010-08-03 09:11:54Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.export.spotdata;

import java.util.Collection;

import net.sf.basedb.core.BioAssay;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.util.formatter.Formatter;

/**
	Represents a bioassay field that is going to be exported. An implementation 
	needs to provide the following information and services:
	<ul>
	<li>A way to extract the needed values based from a bioassay.
	<li>A {@link Formatter} that is used to format the values that are
		extracted before they are written to the file
	<li>A title that is used as a column header for the data
	</ul>


	@author Nicklas
	@version 2.12
	@base.modified $Date: 2010-08-03 11:11:54 +0200 (Tue, 03 Aug 2010) $
*/
public interface AssayField
	extends ExportableField
{

	/**
		Get the values for the given bioassay.
		@param dc The DbControl that is used for database access
		@param assay The bioassay to get the value(s) from
		
		@return A collection with one or more values, or null or an
			empty collection if there is no value for the given
			bioassay
	*/
	public Collection<?> getAssayValue(DbControl dc, BioAssay assay);
	
	/**
		A boolean flag indicating if the field is an annotation or not.
		@return TRUE if the field is an annotation, FALSE if not
		@since 2.16
	*/
	public boolean isAnnotation();
	
}
