/**
	$Id: InvalidAndModifiedFilter.java 5607 2011-04-15 07:52:28Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.manager.filter;

import net.sf.basedb.util.extensions.manager.ExtensionsFile;
import net.sf.basedb.util.filter.Filter;

/**
	Filter implementation for extension files that 
	allow modified but invalid files to pass.
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-04-15 09:52:28 +0200 (Fri, 15 Apr 2011) $
*/
public class InvalidAndModifiedFilter
	implements Filter<ExtensionsFile>
{
	
	private static final org.apache.log4j.Logger log = 
		org.apache.log4j.LogManager.getLogger("net.sf.basedb.util.extensions.manager.filter.InvalidAndModifiedFilter");

	
	/**
		Create a new filter.
	*/
	public InvalidAndModifiedFilter()
	{}
	
	/*
		From the Filter interface
		-------------------------
	*/
	@Override
	public boolean evaluate(ExtensionsFile xtFile)
	{
		if (xtFile.isValid() && !xtFile.hasError()) 
		{
			log.info("File has no errors (skipping): " + xtFile);
			return false;
		}
		
		if (!xtFile.wasModified())
		{
			log.info("File is not modified (skipping): " + xtFile);
			return false;
		}
		
		return true;
	}
	// -------------------------
	
	
}
