/**
	$Id: ItemTypeFilter.java 4740 2009-02-05 13:39:25Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.filter;

import net.sf.basedb.core.Item;
import net.sf.basedb.util.filter.Filter;
import net.sf.basedb.util.overview.Node;

/**
	A filter implementation that mathces item types on nodes.
	It will evaluate to true for all {@link Node}:s whose
	{@link Node#getItemType()} method matches the given item
	type.

	@author Nicklas
	@version 2.10
	@base.modified $Date: 2009-02-05 14:39:25 +0100 (Thu, 05 Feb 2009) $
*/
public class ItemTypeFilter
	implements Filter<Node>
{
	
	private final Item itemType;
	
	/**
		Create a filter that finds nodes that has an attached item of the
		given item type.
		@param itemType The item type to look for
	*/
	public ItemTypeFilter(Item itemType)
	{
		this.itemType = itemType;
	}

	/*
		From the Filter interface
		-------------------------
	*/
	@Override
	public boolean evaluate(Node node)
	{
		return node.getItemType() == itemType;
	}
	// -----------------------------
}
