/**
	$Id: TagLoader.java 5651 2011-06-08 13:00:33Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.overview.loader;

import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.Extract;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.PermissionDeniedException;
import net.sf.basedb.core.Tag;
import net.sf.basedb.util.overview.Node;
import net.sf.basedb.util.overview.OverviewContext;
import net.sf.basedb.util.overview.Validator;
import net.sf.basedb.util.overview.node.ChildNodeDirection;
import net.sf.basedb.util.overview.node.NameableNameGenerator;
import net.sf.basedb.util.overview.node.NodeFactory;

/**
	Node loader implementation for tags. Tag nodes are loaded as
	end-point property nodes with no children. It can't be a root 
	node or a forward/reverse-loading node.
	<p>
	Validations:
	<ul>
	<li>Incorrect tag type: {@link Validator#INCORRECT_TAGTYPE}
	</ul>
	
	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-06-08 15:00:33 +0200 (Wed, 08 Jun 2011) $
*/
public class TagLoader
	extends BasicItemNodeLoader<Tag>
{
	
	public TagLoader()
	{
		super(Item.TAG, DENY_ROOT_NODE, 
				new NameableNameGenerator<Tag>("tag", "Tag"));
	}
	
	/*
		From the NodeLoader interface
		------------------------------
	*/
	@Override
	public Node createPropertyNode(DbControl dc, OverviewContext context, Node parentNode)
	{
		Tag tag = null;
		boolean denied = false;
		try
		{
			BasicItem parentItem = (BasicItem)parentNode.getItem(dc);
			if (parentItem instanceof Extract)
			{
				tag = ((Extract)parentItem).getTag();
			}
			// If there are other items with a tag
			// we should add more cases here
		}
		catch (PermissionDeniedException ex)
		{
			denied = true;
		}
		
		NodeFactory<Tag> nf = getNodeFactory(dc, context);
		Node hardwareNode = createItemNode(nf, tag, tag, denied, 
				parentNode, ChildNodeDirection.NONE);
		return hardwareNode;
	}
	// -----------------------------------
	
}
