/**
	$Id: VersionInfo.java 5607 2011-04-15 07:52:28Z nicklas $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.info;

import java.io.Serializable;

/**
 	Information about the version the BASE server is running.
 	
  	@author Nicklas
 	@version 2.5
 */
public class VersionInfo
	implements Serializable, Transferable
{
	private static final long serialVersionUID = 9189853948028180946L;

	private int major;
	private int minor;
	private int maintenance;
	private int build;
	private int schema;
	
	/**
	 	Creates a new empty info object
	 */
	public VersionInfo()
	{}

	/**
		@return Returns the build number
		@see net.sf.basedb.core.Application#getBuild()
	*/
	public int getBuild() 
	{
		return build;
	}

	public void setBuild(int build) 
	{
		this.build = build;
	}

	/**
	 	@return Returns the maintenance version
	 	@see net.sf.basedb.core.Application#getMaintenanceVersion()
	 	@since 3.0 (was returning a String in 2.x)
	*/
	public int getMaintenance()
	{
		return maintenance;
	}

	public void setMaintenance(int maintenance) 
	{
		this.maintenance = maintenance;
	}

	/**
	 	@return Returns the major version
	 	@see net.sf.basedb.core.Application#getMajorVersion()
	 	@since 3.0 (was returning a String in 2.x)
	*/
	public int getMajor() 
	{
		return major;
	}

	public void setMajor(int major) 
	{
		this.major = major;
	}

	/**
	 	@return Returns the minor version
	 	@see net.sf.basedb.core.Application#getMinorVersion()
	 	@since 3.0 (was returning a String in 2.x)
	*/
	public int getMinor() 
	{
		return minor;
	}

	public void setMinor(int minor) 
	{
		this.minor = minor;
	}

	/**
	 	@return Returns the database schema version
	 	@see net.sf.basedb.core.Application#getSchemaVersion()
	*/
	public int getSchema() 
	{
		return schema;
	}

	public void setSchema(int schema) 
	{
		this.schema = schema;
	}

	/**
		Combine the versions to a string: major.minor.maintenance (build; schema)
	*/
	public String toString()
	{
		return "BASE " + major + "." + minor +
			"." + maintenance + " (build #" + build +
			"; schema #" + schema + ")";
	}
	

}
