/*
 $Id$

	Copyright (C) 2010 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

 BASE is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3
 of the License, or (at your option) any later version.

 BASE is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with BASE. If not, see <http://www.gnu.org/licenses/>.
 */

import java.util.Collection;
import java.util.Date;

import net.sf.basedb.core.BaseException;
import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.DbControl;
import net.sf.basedb.core.DerivedBioAssay;
import net.sf.basedb.core.Extract;
import net.sf.basedb.core.Formula;
import net.sf.basedb.core.Item;
import net.sf.basedb.core.Metadata;
import net.sf.basedb.core.PhysicalBioAssay;
import net.sf.basedb.core.Platform;
import net.sf.basedb.core.RawBioAssay;
import net.sf.basedb.core.Metadata.PropertyPath;
import net.sf.basedb.core.SystemItems;
import net.sf.basedb.core.Tag;

public class TestMetadata
{
	
	public static void main(String[] args)
	{
		TestUtil.checkArgs(args);
		TestUtil.begin();
		ok = test_all();
		TestUtil.stop();
	}
	
	private static boolean ok = true;

	public static Boolean test_all()
	{
		write("++Testing metadata");
		// Simple property on root class
		PropertyPath<RawBioAssay, String> name = 
			test_create_property_path(RawBioAssay.class, "name", false);
		// Association + id property
		PropertyPath<RawBioAssay, Integer> scan = 
			test_create_property_path(RawBioAssay.class, "parentBioAssay.id", false);
		// Null association
		PropertyPath<RawBioAssay, String> protocolName = 
			test_create_property_path(RawBioAssay.class, "parentBioAssay.protocol.name", false);
		// Date value
		PropertyPath<RawBioAssay, Date> hybDate = 
			test_create_property_path(RawBioAssay.class, "parentBioAssay.physicalBioAssay.creationEvent.entryDate", false);
		// Long path + case insensitive
		PropertyPath<RawBioAssay, String> design = 
			test_create_property_path(RawBioAssay.class, "ParentBioAssay.PhysicalBioAssay.Arrayslide.Arraybatch.Arraydesign", false);
		// Component
		PropertyPath<Formula, Float> formulaMinValue = 
			test_create_property_path(Formula.class, "coloring.minValue", false);
		// Collection
		PropertyPath<Formula, Collection<String>> formulaFormulas = 
			test_create_property_path(Formula.class, "formulas", false);
		// THE TESTS BELOW ARE INVALID PROPERTY PATHS
		// Unknown paths
		test_create_property_path(RawBioAssay.class, "foo", true);
		test_create_property_path(RawBioAssay.class, "name.foo", true);
		test_create_property_path(RawBioAssay.class, "parentBioAssay.foo", true);
		
		// Collection of entities should fail
		test_create_property_path(DerivedBioAssay.class, "children", true);
		
		int designId = TestArrayDesign.test_create(Platform.GENERIC, true);
		int batchId = TestArrayBatch.test_create(designId, true);
		int slideId = TestArraySlide.test_create(batchId, true);
		int labelId = TestTag.test_create("Test label", SystemItems.getId(Tag.LABEL), true);
		int labeledExtractId = TestExtract.test_create(0, "Test extract", SystemItems.getId(Extract.LABELED), labelId, true);
		int hybId = TestPhysicalBioAssay.test_create(slideId, "Test hyb", SystemItems.getId(PhysicalBioAssay.HYBRIDIZATION), 1, labeledExtractId);
		int scanId = TestDerivedBioAssay.test_create_root("Test scan", hybId, SystemItems.getId(DerivedBioAssay.SCAN), 0, 0, 0);
		int rawId = TestRawBioAssay.test_create(Platform.GENERIC, "genepix", "My raw bioassay", 
				scanId, labeledExtractId, 0, 0, designId, true);
		int formulaId = TestFormula.test_create("Test metadata", Formula.Type.COLUMN_EXPRESSION, 
			"genepix",  new String[] { "ch(1) + ch(2)" }, true);
		int pluginId = TestPluginDefinition.test_get("net.sf.basedb.plugins.AnnotationFlatFileImporter");
		
		test_use_property_path(name, Item.RAWBIOASSAY, rawId);
		test_use_property_path(scan, Item.RAWBIOASSAY, rawId);
		test_use_property_path(protocolName, Item.RAWBIOASSAY, rawId);
		test_use_property_path(hybDate, Item.RAWBIOASSAY, rawId);
		test_use_property_path(design, Item.RAWBIOASSAY, rawId);
		test_use_property_path(formulaMinValue, Item.FORMULA, formulaId);
		test_use_property_path(formulaFormulas, Item.FORMULA, formulaId);
		
		if (TestUtil.waitBeforeDelete()) TestUtil.waitForEnter();
		
		TestFormula.test_delete(formulaId);
		TestRawBioAssay.test_delete(rawId);
		TestDerivedBioAssay.test_delete(scanId);
		TestPhysicalBioAssay.test_delete(hybId);
		TestExtract.test_delete(labeledExtractId);
		TestTag.test_delete(labelId);
		TestArraySlide.test_delete(slideId);
		TestArrayBatch.test_delete(batchId);
		TestArrayDesign.test_delete(designId);
		
		write("++Testing metadata "+(ok ? "OK" : "Failed")+"\n");
		return ok;
	}
	
	static <I, V> PropertyPath<I, V> test_create_property_path(Class<I> itemClass, String path, boolean shouldFail)
	{
		PropertyPath<I, V> propertyPath = null;;
		try
		{
			Throwable t = null;
			try
			{
				Metadata<I> metadata = Metadata.getInstance(itemClass);
				propertyPath = metadata.getPropertyPath(path, true);
			}
			catch (Throwable t1)
			{
				t = t1;
			}
			if (shouldFail)
			{
				if (t == null) throw new BaseException("Expected path failure");
				write("--Create property path: "+propertyPath+" OK [" + t.getMessage() + "]");
			}
			else
			{
				if (t != null) throw t;
				write("--Create property path '"+propertyPath+"' OK");
			}
		}
		catch (Throwable ex)
		{
			write("--Create property path '" + itemClass.getSimpleName() + "."+path+"' FAILED");
			ex.printStackTrace();
			ok = false;
		}
		return propertyPath;
	}
	
	@SuppressWarnings("unchecked")
	static void test_use_property_path(PropertyPath path, Item itemType, int itemId)
	{
		if (itemId == 0 || path == null) return;
		DbControl dc = null;
		try
		{
			dc = TestUtil.getDbControl();
			BasicItem item = itemType.getById(dc, itemId);
			Object value = path.getValue(dc, item);
			write("--Use property path '"+path+"' OK: " + value);
		}
		catch (Throwable ex)
		{
			write("--Use property path '"+path+"' FAILED");
			ex.printStackTrace();
			ok = false;
		}
		finally
		{
			if (dc != null) dc.close();
		}
	}
	
	static void write(String message)
	{
		System.out.println(message);
	}
}
