/* $Id: plugin.js 5372 2010-06-24 12:28:06Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	JavaScript functions for managing plugins and configurations.

	@author Nicklas
	@version 2.0
*/
var Plugins = new PluginsClass();

function PluginsClass()
{
	this.allPlugins = new Array();
	
	this.populateLists = function(pluginList)
	{
		var option = new Option('- auto detect (all) -', '-1');
		pluginList[pluginList.length] = option;
		option.className = 'selectoptionautodetect';
		var numAutodetecting = 0;
		for (var i = 0; i < this.allPlugins.length; i++)
		{
			var plugin = this.allPlugins[i];
			var option = new Option(plugin.name, plugin.id);
			if (plugin.autodetection) 
			{
				option.text += ' ×';
				numAutodetecting++;
			}
			pluginList[pluginList.length] = option;
			pluginList[pluginList.length-1].plugin = plugin;
			option.className = 'selectoptionheader';
			if (plugin.requiresConfiguration)
			{
				option.disabled = true;
			}
			
			if (plugin.supportsConfigurations && plugin.configurations.length > 0)
			{
				if (plugin.autodetection)
				{
					var option = new Option(' ├ auto detect (' + plugin.name + ') -', '-1');
					option.className = 'selectoptionautodetect';
					pluginList[pluginList.length] = option;
					pluginList[pluginList.length-1].plugin = plugin;
				}
				for (var j = 0; j < plugin.configurations.length; j++)
				{
					var conf = plugin.configurations[j];
					var name = conf.name;
					var prefix = j == plugin.configurations.length-1 ? ' └ ' : ' ├ '
					var option = new Option(prefix+name, conf.id);
					pluginList[pluginList.length] = option;
					pluginList[pluginList.length-1].plugin = plugin;
					pluginList[pluginList.length-1].configuration = conf;
				}
			}
			
		}
		if (numAutodetecting == 0)
		{
			pluginList[0] = null;
		}
	}
	
	/*
	this.updateConfigurationsList = function(plugin, list)
	{
		list.length = 0;
		if (plugin)
		{
			if (plugin.supportsConfigurations && plugin.configurations.length > 0)
			{
				var selectFirstConfig = plugin.configurations.length == 1;
				if (plugin.autodetection)
				{
					list[list.length] = new Option('- auto detect -', '-1');
				}
				if (!plugin.requiresConfiguration)
				{
					list[list.length] = new Option('- none -', '0');
				}
				for (var i = 0; i < plugin.configurations.length; i++)
				{
					var conf = plugin.configurations[i];
					list[list.length] = new Option(conf.name, conf.id, selectFirstConfig && i == 0);
					list[list.length-1].configuration = conf;
				}
			}
		}
		else
		{
			list[list.length] = new Option('- auto detect -', '-1');
		}
	}
	*/
	
}


// Create a new plugin object
function Plugin(id, name, autodetection, supportsConfigurations, requiresConfiguration)
{
	this.id = id;
	this.name = name;
	this.autodetection = autodetection;
	this.supportsConfigurations = supportsConfigurations;
	this.requiresConfiguration = requiresConfiguration;
	
	this.configurations = new Array();
	
	Plugins.allPlugins[Plugins.allPlugins.length] = this;

	this.addConfiguration = function(id, name)
	{
		this.configurations[this.configurations.length] = new Configuration(id, name);
	}

}

function Configuration(id, name)
{
	this.id = id;
	this.name = name;
}

